==> aria2-1.8.1.tar.xz: aria2-1.8.1/src/MetalinkParserState.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef _D_METALINK_PARSER_STATE_H_
#define _D_METALINK_PARSER_STATE_H_

#include "common.h"
#include <map>
#include <string>

namespace aria2 {

class MetalinkParserStateMachine;

class MetalinkParserState
{
public:
  virtual ~MetalinkParserState() {}

  virtual void beginElement
  (MetalinkParserStateMachine* stm,
   const std::string& name,
   const std::map<std::string, std::string>& attrs) = 0;
  
  virtual void endElement
  (MetalinkParserStateMachine* stm,
   const std::string& name, const std::string& characters) = 0;

  virtual bool needsCharactersBuffering() const = 0;
};

} // namespace aria2

#endif // _D_METALINK_PARSER_STATE_H_

==> aria2-1.12.0.tar.xz: aria2-1.12.0/src/MetalinkParserState.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef D_METALINK_PARSER_STATE_H
#define D_METALINK_PARSER_STATE_H

#include "common.h"

#include <vector>
#include <string>

namespace aria2 {

class MetalinkParserStateMachine;

struct XmlAttr {
  std::string localname;
  std::string prefix;
  std::string nsUri;
  std::string value;

  XmlAttr();
  XmlAttr(const XmlAttr& attr);
  ~XmlAttr();
  XmlAttr& operator=(const XmlAttr&);
};

class MetalinkParserState
{
public:
  virtual ~MetalinkParserState() {}

  virtual void beginElement
  (MetalinkParserStateMachine* stm,
   const std::string& localname,
   const std::string& prefix,
   const std::string& nsUri,
   const std::vector<XmlAttr>& attrs) {}
  
  virtual void endElement
  (MetalinkParserStateMachine* stm,
   const std::string& localname,
   const std::string& prefix,
   const std::string& nsUri,
   const std::string& characters) {}

  virtual bool needsCharactersBuffering() const
  {
    return false;
  }
};

} // namespace aria2

#endif // D_METALINK_PARSER_STATE_H
